==> pyqt6-forms-0.2.2.tar.gz: pyqt6-forms-0.2.2/setup.py <==
# Импорт недавно установленного пакета setuptools.
import setuptools

# Открытие README.md и присвоение его long_description.
# with open("./README.md", "r") as fh:
#     long_description = fh.read()

# Определение requests как requirements для того, чтобы этот пакет работал. Зависимости проекта.
# with open("requirements.txt", "r") as f:
#     requirements = f.read().split('\n')

# Функция, которая принимает несколько аргументов. Она присваивает эти значения пакету.
setuptools.setup(
    # Имя дистрибутива пакета. Оно должно быть уникальным, поэтому добавление вашего имени пользователя в конце является обычным делом.
    name="pyqt6-forms",
    # Номер версии вашего пакета. Обычно используется семантическое управление версиями.
    version="0.2.2",
    # Имя автора.
    author="gloger2003 (Anight Studio)",
    # Его почта.
    author_email="excelsior7554@gmail.com",
    # Краткое описание, которое будет показано на странице PyPi.
    description="Forms for PyQt6",
    # Длинное описание, которое будет отображаться на странице PyPi. Использует README.md репозитория для заполнения.
    long_description="README: https://github.com/gloger2003/pyqt6-forms",
    # Определяет тип контента, используемый в long_description.
    long_description_content_type="text/markdown",
    # URL-адрес, представляющий домашнюю страницу проекта. Большинство проектов ссылаются на репозиторий.
    url="https://github.com/gloger2003/pyqt6-forms",
    # Находит все пакеты внутри проекта и объединяет их в дистрибутив.
        packages=setuptools.find_packages(),
        # requirements или dependencies, которые будут установлены вместе с пакетом, когда пользователь установит его через pip.
        # install_requires=requirements,
        # Предоставляет pip некоторые метаданные о пакете. Также отображается на странице PyPi.
        classifiers=[
            "Programming Language :: Python :: 3.10",
            "License :: OSI Approved :: Apache Software License",
            "Operating System :: OS Independent",
        ],
    # Требуемая версия Python.
    python_requires='>=3.10',
)

==> pyqt6-forms-0.3.0.tar.gz: pyqt6-forms-0.3.0/setup.py <==
# Импорт недавно установленного пакета setuptools.
import setuptools

# Открытие README.md и присвоение его long_description.
with open("../README.md", "r") as fh:
    long_description = fh.read()

# Определение requests как requirements для того, чтобы этот пакет работал. Зависимости проекта.
# with open("requirements.txt", "r") as f:
#     requirements = f.read().split('\n')

# Функция, которая принимает несколько аргументов. Она присваивает эти значения пакету.
setuptools.setup(
    # Имя дистрибутива пакета. Оно должно быть уникальным, поэтому добавление вашего имени пользователя в конце является обычным делом.
    name="pyqt6-forms",
    # Номер версии вашего пакета. Обычно используется семантическое управление версиями.
    version="0.3.0",
    # Имя автора.
    author="gloger2003 (Anight Studio)",
    # Его почта.
    author_email="excelsior7554@gmail.com",
    # Краткое описание, которое будет показано на странице PyPi.
    description="Forms for PyQt6",
    # Длинное описание, которое будет отображаться на странице PyPi. Использует README.md репозитория для заполнения.
    # long_description="README: https://github.com/gloger2003/pyqt6-forms",
    long_description=long_description,
    # Определяет тип контента, используемый в long_description.
    long_description_content_type="text/markdown",
    # URL-адрес, представляющий домашнюю страницу проекта. Большинство проектов ссылаются на репозиторий.
    url="https://github.com/gloger2003/pyqt6-forms",
    # Находит все пакеты внутри проекта и объединяет их в дистрибутив.
        packages=setuptools.find_packages(),
        # requirements или dependencies, которые будут установлены вместе с пакетом, когда пользователь установит его через pip.
        # install_requires=requirements,
        # Предоставляет pip некоторые метаданные о пакете. Также отображается на странице PyPi.
        classifiers=[
            "Programming Language :: Python :: 3.10",
            "License :: OSI Approved :: Apache Software License",
            "Operating System :: OS Independent",
        ],
    # Требуемая версия Python.
    python_requires='>=3.10',
)
